#!/usr/bin/env python
#
# Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
# All rights reserved.
# Contact: Nokia Corporation (directui@nokia.com)
#
# This file is part of applauncherd.
#
# If you have questions regarding the use of this file, please contact
# Nokia at directui@nokia.com.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License version 2.1 as published by the Free Software Foundation
# and appearing in the file LICENSE.LGPL included in the packaging
# of this file.

import unittest
import commands
import os
import time
import sys
from os.path import basename

class prestart_tests (unittest.TestCase):
    def setUp(self):
        #setup here
        print("Executing SetUp\n")
        if self.get_pid("applifed") == None:
            os.system("initctl start xsession/applifed")
            time.sleep(20)

    def tearDown(self):
        if self.get_pid("applifed") == None:
            os.system("initctl start xsession/applifed")
            time.sleep(20)
        print("Executing TearDown\n")
    
    def get_pid(self, appname):
        temp = basename(appname)[:14]
        st, op = commands.getstatusoutput("pgrep %s" % temp)
        print("The Pid of %s is: %s\n" %(appname, op))
        if st == 0:
            return op
        else:
            return None
    #Testcases
    def prestarted_apps_from_conf(self):
        """
        This is a function that parses the nokia.conf file to get
        which applications should be prestarted.  
        """
        st, op = commands.getstatusoutput("cat /etc/prestart/nokia.conf")
        app_list1, app_list2 = [], []
        l1 = op.split("\n")
        for i in l1:
            if i.startswith("    <application name="):
                app_list1.append(i)
        for j in app_list1:
            app_list2.append(j.split("name=")[1].split(" ")[0].strip('"'))
        
        #Replace "browser" with "grob" as the application binary for "browser" is "grob"
        if app_list2.__contains__("browser"):
            app_list2[app_list2.index("browser")] = "grob"

        return app_list2

    def prestarted_apps_from_plist(self):
        """
        This function parses the process list to get the applications
        that are prestarted
        """
        st, op = commands.getstatusoutput("ps ax | grep prestart")
        l1 = op.split("\n")
        app_list = []
        for i in l1:
            x = i.split("    ")[1]
            if not x.startswith(" /usr/bin/invoker") and x.startswith(" /usr/bin/"):
                app_list.append(x.split(" ")[1].split("/usr/bin/")[1])
        return app_list

    def test_prestarted_app_list(self):
        """
        First test that applifed is running and all applications
        defined in the conf file are prestarted. 
        Then stop applifed and check that all the applications
        prestarted by applifed are killed
        """
        
        #Check that all the apps defined in conf file are prestarted
        apps_from_conf = self.prestarted_apps_from_conf()
        print("Apps to be prestared as defined in conf file: %s\n" %apps_from_conf)

        apps_from_plist = self.prestarted_apps_from_plist()
        print("The running prestarted apps: %s\n" %apps_from_plist)

        cmp_set = set(apps_from_conf) & set(apps_from_plist)
        print("The set of common apps: %s\n" %cmp_set)

        self.assert_(cmp_set == set(apps_from_conf), "All applications are not prestarted")

        #Check that all the apps prestared by applifed are killed when applifed is stopped
        print("Stop applifed and wait for some time\n")
        os.system("initctl stop xsession/applifed")
        time.sleep(2)

        apps_from_plist = self.prestarted_apps_from_plist()
        print("The running prestarted apps: %s\n" %apps_from_plist)

        cmp_set = set(apps_from_conf) & set(apps_from_plist)
        print("The set of uncommon apps: %s\n" %cmp_set)

        self.assert_(cmp_set == set([]), "All applications are not killed")




if __name__ == '__main__':
    # When run with testrunner, for some reason the PATH doesn't include
    # the tools/bin directory
    if os.getenv('_SBOX_DIR') != None:
        os.environ['PATH'] = os.getenv('PATH') + ":" + os.getenv('_SBOX_DIR') + '/tools/bin'
        using_scratchbox = True

    tests = sys.argv[1:]

    mysuite = unittest.TestSuite(map(prestart_tests, tests))
    result = unittest.TextTestRunner(verbosity=2).run(mysuite)

    if not result.wasSuccessful():
        sys.exit(1)

    sys.exit(0)
